# Fault Tolerance

Building systems that survive failures is essential.

## Redundancy

Deploy multiple instances of each component.

## Circuit Breakers

Prevent cascading failures by stopping requests to failing services.

## Health Checks

Monitor system health and automatically recover from failures.

### Liveness Checks

Verify that a service is running.

### Readiness Checks

Verify that a service is ready to accept traffic.
